==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fSipush.h <==
// class soot.coffi.Instruction_Sipush

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class db1b554fba590aeb soot_coffi_Instruction__5fSipush
// @dep_class ef982fd7e7c40bf6 soot_coffi_Instruction__5fint

// header file dependencies
// @dep_header soot_coffi_Instruction__5fint

#include "soot/coffi/Instruction__5fint.h"

#ifndef _JC_soot_coffi_Instruction__5fSipush_H_
#define _JC_soot_coffi_Instruction__5fSipush_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fSipush$sub_refs	_jc_soot_coffi_Instruction__5fSipush$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fSipush$sub_nonrefs	_jc_soot_coffi_Instruction__5fSipush$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fSipush$refs	_jc_soot_coffi_Instruction__5fSipush$refs;
typedef struct _jc_soot_coffi_Instruction__5fSipush$nonrefs	_jc_soot_coffi_Instruction__5fSipush$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fSipush$object	_jc_soot_coffi_Instruction__5fSipush$object;

typedef const struct _jc_soot_coffi_Instruction__5fSipush$vmethods	_jc_soot_coffi_Instruction__5fSipush$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fSipush$vtable	_jc_soot_coffi_Instruction__5fSipush$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fSipush$vtype	_jc_soot_coffi_Instruction__5fSipush$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fSipush$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fSipush$object *);
extern void _jc_soot_coffi_Instruction__5fSipush$method$_init$7f1776288300b98d(_jc_env *, struct _jc_soot_coffi_Instruction__5fSipush$object *, jint);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fSipush$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fSipush$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fint$vmethods	soot_coffi_Instruction__5fint;
	_jc_soot_coffi_Instruction__5fSipush$vmethods	soot_coffi_Instruction__5fSipush;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fSipush$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fSipush$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fSipush$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fSipush$refs {
    _jc_soot_coffi_Instruction__5fSipush$sub_refs	soot_coffi_Instruction__5fSipush;
    _jc_soot_coffi_Instruction__5fint$sub_refs	soot_coffi_Instruction__5fint;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fSipush$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fSipush$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fint$sub_nonrefs	soot_coffi_Instruction__5fint;
    _jc_soot_coffi_Instruction__5fSipush$sub_nonrefs	soot_coffi_Instruction__5fSipush;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fSipush$object {
	_jc_soot_coffi_Instruction__5fSipush$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fSipush$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fSipush$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fSipush$vtype _jc_soot_coffi_Instruction__5fSipush$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fSipush, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fSipush$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fSipush_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fSipush.h <==
// class soot.coffi.Instruction_Sipush

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class db1b554fba590aeb soot_coffi_Instruction__5fSipush
// @dep_class ef982fd7e7c40bf6 soot_coffi_Instruction__5fint

// header file dependencies
// @dep_header soot_coffi_Instruction__5fint

#include "soot/coffi/Instruction__5fint.h"

#ifndef _JC_soot_coffi_Instruction__5fSipush_H_
#define _JC_soot_coffi_Instruction__5fSipush_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fSipush$sub_refs	_jc_soot_coffi_Instruction__5fSipush$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fSipush$sub_nonrefs	_jc_soot_coffi_Instruction__5fSipush$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fSipush$refs	_jc_soot_coffi_Instruction__5fSipush$refs;
typedef struct _jc_soot_coffi_Instruction__5fSipush$nonrefs	_jc_soot_coffi_Instruction__5fSipush$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fSipush$object	_jc_soot_coffi_Instruction__5fSipush$object;

typedef const struct _jc_soot_coffi_Instruction__5fSipush$vmethods	_jc_soot_coffi_Instruction__5fSipush$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fSipush$vtable	_jc_soot_coffi_Instruction__5fSipush$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fSipush$vtype	_jc_soot_coffi_Instruction__5fSipush$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fSipush$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fSipush$object *) _JC_JCNI_ATTR;
extern void _jc_soot_coffi_Instruction__5fSipush$method$_init$7f1776288300b98d(_jc_env *, struct _jc_soot_coffi_Instruction__5fSipush$object *, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fSipush$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fSipush$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fint$vmethods	soot_coffi_Instruction__5fint;
	_jc_soot_coffi_Instruction__5fSipush$vmethods	soot_coffi_Instruction__5fSipush;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fSipush$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fSipush$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fSipush$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fSipush$refs {
    _jc_soot_coffi_Instruction__5fSipush$sub_refs	soot_coffi_Instruction__5fSipush;
    _jc_soot_coffi_Instruction__5fint$sub_refs	soot_coffi_Instruction__5fint;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fSipush$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fSipush$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fint$sub_nonrefs	soot_coffi_Instruction__5fint;
    _jc_soot_coffi_Instruction__5fSipush$sub_nonrefs	soot_coffi_Instruction__5fSipush;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fSipush$object {
	_jc_soot_coffi_Instruction__5fSipush$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fSipush$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fSipush$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fSipush$vtype _jc_soot_coffi_Instruction__5fSipush$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fSipush, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fSipush$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fSipush_H_ */
